@@ -83,7 +83,7 @@ public:
 	QList<HistoryEvent> history;
 	int historyPos;
 
-	QVector<int>  m_cage;
+	QList<int>    m_cage;
 	int           m_cageValue;
 	CageOperator  m_cageOperator;
 	int           m_currentCageSaved;
@@ -96,7 +96,7 @@ void Game::Private::undo() {
 	HistoryEvent event(history[--historyPos]);
 	event.undoOn(state);
 	
-	const QVector<int>& indices = event.cellIndices();
+	const QList<int>& indices = event.cellIndices();
 	if(indices.count() > 10) {
 		Q_EMIT fullChange();
 	} else {
@@ -112,7 +112,7 @@ void Game::Private::redo() {
 	HistoryEvent event(history[historyPos++]);
 	event.redoOn(state);
 
-	const QVector<int>& indices = event.cellIndices();
+	const QList<int>& indices = event.cellIndices();
 	if(indices.count() > 10) {
 		Q_EMIT fullChange();
 	} else {
@@ -532,11 +532,11 @@ void Game::deleteCageAt (int pos, SKGraph * g)
 	    }
 	    // If the right-click was on a cage, delete it.
 	    if (cageNumP1 > 0) {
-		if(KMessageBox::questionYesNo (messageParent(),
+		if(KMessageBox::questionTwoActions (messageParent(),
 		       i18n("Do you wish to delete this cage?"),
 		       i18n("Delete Cage"), KStandardGuiItem::del(),
 		       KStandardGuiItem::cancel(), QStringLiteral("CageDelConfirm"))
-		       == KMessageBox::No) {
+		       == KMessageBox::SecondaryAction) {
 		    return;
 		}
 		if (g->cage(cageNumP1-1).size() == 1) {	// Erase digit.
